@@ -63,6 +63,11 @@ def main():
     parser.add_argument(
         "-q", "--quiet", action="store_true", help="suppress standard output"
     )
+    parser.add_argument(
+        "--fuzzy",
+        action="store_true",
+        help="extract Google Drive's file ID",
+    )
     parser.add_argument(
         "--id",
         action="store_true",
@@ -97,9 +102,11 @@ def main():
             args.output = sys.stdout
 
     if args.id:
-        url = "https://drive.google.com/uc?id={id}".format(id=args.url_or_id)
+        url = None
+        id = args.url_or_id
     else:
         url = args.url_or_id
+        id = None
 
     filename = download(
         url=url,
@@ -109,6 +116,8 @@ def main():
         speed=args.speed,
         use_cookies=not args.no_cookies,
         verify=not args.no_check_certificate,
+        id=id,
+        fuzzy=args.fuzzy,
     )
 
     if filename is None:
