@@ -67,13 +67,15 @@ def get_url_from_gdrive_confirmation(contents):
 
 
 def download(
-    url,
+    url=None,
     output=None,
     quiet=False,
     proxy=None,
     speed=None,
     use_cookies=True,
     verify=True,
+    id=None,
+    fuzzy=False,
 ):
     """Download file from URL.
 
@@ -81,7 +83,7 @@ def download(
     ----------
     url: str
         URL. Google Drive URL is also supported.
-    output: str, optional
+    output: str
         Output filename. Default is basename of URL.
     quiet: bool
         Suppress terminal output. Default is False.
@@ -95,12 +97,21 @@ def download(
         Either a bool, in which case it controls whether the server’s TLS
         certificate is verified, or a string, in which case it must be a path
         to a CA bundle to use. Default is True.
+    id: str
+        Google Drive's file ID.
+    fuzzy: bool
+        Fuzzy extraction of Google Drive's file Id.
 
     Returns
     -------
     output: str
         Output filename.
     """
+    if not (id is None) ^ (url is None):
+        raise ValueError("Either url or id has to be specified")
+    if id is not None:
+        url = "https://drive.google.com/uc?id={id}".format(id=id)
+
     url_origin = url
     sess = requests.session()
 
@@ -119,7 +130,13 @@ def download(
         sess.proxies = {"http": proxy, "https": proxy}
         print("Using proxy:", proxy, file=sys.stderr)
 
-    file_id, is_download_link = parse_url(url)
+    gdrive_file_id, is_gdrive_download_link = parse_url(url, warning=not fuzzy)
+
+    if fuzzy and gdrive_file_id:
+        # overwrite the url with fuzzy match of a file id
+        url = "https://drive.google.com/uc?id={id}".format(id=gdrive_file_id)
+        url_origin = url
+        is_gdrive_download_link = True
 
     headers = {
         "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36"  # NOQA
@@ -145,7 +162,7 @@ def download(
         if "Content-Disposition" in res.headers:
             # This is the file
             break
-        if not (file_id and is_download_link):
+        if not (gdrive_file_id and is_gdrive_download_link):
             break
 
         # Need to redirect with confirmation
@@ -163,7 +180,7 @@ def download(
             print("\n\t", url_origin, "\n", file=sys.stderr)
             return
 
-    if file_id and is_download_link:
+    if gdrive_file_id and is_gdrive_download_link:
         m = re.search('filename="(.*)"', res.headers["Content-Disposition"])
         filename_from_url = m.groups()[0]
     else:
